bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 36. Aventiure
___________________________________________________ #### Auentv wie drie kvnige mit Ezele vn– mit <ir> swester #### vmbe die Svone reiten
| ### <Nv> bindet abe die helme sprach do Hagene ### ia lazen wir den Hvnen so vil ze chlagene ### daz si der hochgecite vergezzent nimmer hie ### waz hilfet nv Chriemh' daz si vns ze Rine niht enlie ### Do entwaffent da dez hovbet manic ritter gvot ### si sazen vf den veigen die vor in in daz blvot ### waren in dem strite mit dem tode chomen ### sit wart der Ezeln geste vil vbel govme genomen
###### 2138 | ### Vor abendes zite geschvof der kunic daz ### vn– ovch div kvniginne daz iz versvochten baz ### die hvnischen rechen dvrch der geste leit ### des man an si gerte die helde warens bereit
###### 2139 | ### Sich hvob ein stvrme herte hier vz vn– ovch dar in ### Danchwart [77r]Hagenen brvoder dvrch degenlichen sin ### spranch vor sinen herren zen vinden vz der <tvr> ### sich versahen sines todes er chom gesunder wol dar fvor
###### 2140 | ### Der herte strit do werte vnz iz div naht benam ### do werten sich die geste als iz in wol gezam ### den Ezeln degenen den svmerlangen tac ### hey waz noch der helede vor in veige gelac
| ### Zeinen svnewenden der groze mort geschach ### daz div kuniginne ir hercenleit errach ### an ir næhsten magen vn– svs an manigem man ### da von der kvnec Ezele vil manigen <siechchen> gewan
###### 2142 | ### Sine het der grozen slahte also niht gedaht ### si het ez in ir ahte vil gerne dar zvo brahte ### daz niwan Hagene aleine den lip da hete lan ### do geschvof der vbel tivfel deiz vber si alle mvose ergan
###### 2143 | ### In was des tages zerrvnnen do gie in sorgen not ### si gedahten daz in bezzer wær ein kurcer tot ### denne lange da ze qvelne vf vngefvegiv leit ### eins vrides si do gerten die stolzen ritter gemeit
###### 2144 | ### Si baten daz man bræhte Ezelen dar ### die blvotvarwen degene vn– schone harnasch var ### traten vz dem hvse die drie kvnige her ### sine wessen wem ze klagene div ir vil grozlichen ser
| ### Ezel vn– Chriemh' die chomen beide dar ### daz lant daz was ir eigen des merte sich ir schar ### er sprach zv den kunigen sagt waz welt ir min ### ir wênet vride gewinnen daz chvnde mvelich gesin
###### 2146 | ### vf schaden also grozen als ir mir habt getan ### irn svltes niht geniezen sol ich min lebn han ### min kint daz ir mir slvoget vnde vil der mage min ### des ensol mit sime lebene iwer deheiner chomen hin
###### 2147 | ### Des antwrte Gvnther des twanch vns starchiv not ### allez min gesinde lac von den dinen tot ### an den herbergen wie het ich daz versolt ### ich chom zv dir vf triwe vn– wande daz dv mir wærest holt
###### 2148 | ### Do sprach von Bvrgonden Giselher daz kint ### ir Ezeln rechen die noch hie lebende sint ### waz wizet ir mir degene waz han ich iv getan ### wande ich vil minnekliche in dizze lant geriten han
###### 2149 | ### Si sprachen diner gvete ist al div bvrch vol ### mit iamer zv dem lande ia gvnden wir dir wol ### daz dv nie chomen wærest von Wormez vber Rin ### diz lant ist gar verweiset von dir vn– ovch den magen din
| ### Do sprach in zornes mvote Gvnther der degen ### welt ir dizze starchez hazzen zeiner svone legen ### mit vns vil ellenden deist beidenthalben gvot ### ez ist gar ane schulde swaz vns Ezele getvot
| ### Do sprach der wirt zen gesten min un– iwer leit ### div sint [77v]vil vngeliche div michel arebeit ### des scaden zv den schanden die ich han genomen ### des sol iv deheiner mit dem libe hinnen chomen
###### 2152 | ### Do sprach zv dem kunige Gernot der hochgemvot ### so sol iv got gebieten daz ir wol tvot ### wichet von dem hvose vn– lat vns zvo ziv gan ### sit wir zv dem lebene haben also chleinen wan
###### 2153 | ### Swaz vns geschehn chvenne daz lazet chvrz ergan ### ir habt so vil gesvndr vn– tvrrens vns bestan ### daz si vns stvrmen mvede lazent niht genesen ### sit daz ist vnwendech wir mvzen hie verderbet wesen
###### 2154 | ### Die Ezeln rechen die heten ez nach getan ### <daz> si se vz dem hvse wolden lazen gan ### do daz gehorte Chriemh' ez was ir grimme leit ### des wart den ellenden do der vride widerseit
###### 2155 | ### Neina Hvnen rechen des ir da habet mvot ### ich rat an rehten triwen daz ir des niene tvot ### daz ir die mortrechen iht lazet fvr den sal ### so mvsen iwer frivnde liden totlichen val
###### 2156 | ### Ob ir nv niemen lebte niwan div voten kint ### die minen edeln brveder vn– chomens an den wint ### erchvlten in die ringe so sit ir <alle> verlorn ### ez enwrden chvner degene nie zer werlde geborn
| ### Do sprach der herre Giselher vil liebiv swester min ### wie mohte ich des getrowen do dv mich vber Rin ### so minneklichen ladetes her in dizze lant ### daz mir so grozer chumber solde werden hie bechant
###### 2158 | ### Ich was dir ie getriwe nie getet ich dir leit ### vf solhen gedingen ich her ze hove reit ### daz dv min frivnt wærest vil edeliv swester min ### begench an vns genade sit ez niht anders kan gesin
###### 2159 | ### Ine mag iv niht genaden vngenade ich han ### mir hat von Tronege Hagene so leide getan ### da heime vn– hie ze lande slvoger mir min kint ### des mvzen sere engelten die mit iv da her chomen sint
###### 2160 | ### Welt aber ir mir ze gisel den min vint geben ### sone wil ichz niht versprechen ichn welle ivch lazen leben ### wan ir sit min brvoder vn– einer mvoter chint ### so rede ihz zeiner svone mit disen rechen die hie sint
###### 2161 | ### Nvne welle got von himele sprach do Gernot ### ob vnser tvsent wæren wir legen alle tot ### der sippen diner mage ê wir dir einen man ### gæben hie ze gisel ez wirdet nimmer getan
###### 2162 | ### Wir mvesen doch ersterben sprach do Giselher ### vns enscheidet niemen von ritterlicher wer ### swer gerne mit vns strite wir sin et aber hie ### wande ich der minen frivnde an triwen nie deheinen lie
| ### Do sprach der chvene Danchwart fvr die degene [78r] ### iane stet noh niht eine min brvoder Hagene ### die hie den vride versprechent ez mag in werden leit ### des bringen wir ivch innen daz si iv wêrlich geseit
###### 2164 | ### Do sprach div kvniginne ir helde vil gemeit ### nv get der stiegen naher vn– rechet vnser leit ### daz wil ich immer dienen als ich von rehte sol ### der Hagenen vber mvete der gelon ich im wol
###### 2165 | ### Springet zv dem hvse ir rechen vber al ### so heiz ich vieren enden zvnden an den sal ### so werdent wol errochen elliv vnser leit ### die Ezelen degene die wrden schiere bereit
###### 2166 | ### Die noch hier vzen stvnden die triben si dar in ### mit slegen vn– mit schvzzen wider in den palas hin ### sich wolden nie gescheiden die fursten vn– ir man ### sine mohten von ir triwen niht ein ander verlan
| ### Den sal hiez do zvnden daz Ezeln wip ### do qvelte man den rechen mit fivre da den lip ### daz hvos von einem winde mit chraft vil hohe enbran ### ich wæn ie volch deheinez grozer angest mer gewan
###### 2168 | ### Genvge rvften drinne owe dirre not ### wir mohten michel gerner sin in stvrme tot ### daz mvze got erbarmen wie vlisen wir den lip ### nv richet vngefvoge ir zorn an vns des kvniges wip
###### 2169 | ### Ir einer sprach dar inne wir mvzen ligen tot ### vor rovche vn– ovch vor hizze deist ein grimmiv not ### mir tvot vor starcher hizze der dvrst so rehte we ### des <wen> min leben schiere in disen sorgen zerge
###### 2170 | ### Do sprach von Tronege Hagene ir edeln ritter gvot ### swen der dvrste nv twinge der trinche hie daz blvot ### daz ist in solhen noten noch bezzer danne win ### fvr trinchen vn– fvr spise kan niht anders nv gesin
| ### Do gie der rechen einer do er einen toten vant ### er kniet im zv der wnden den helm er abe gebant ### do begvnder trinchen daz vliezende blvot ### swie vngewon er des wære ez dvhte in groezlichen gvot
###### 2172 | ### Nv lon iv got von himele sprach der mvde man ### daz ich von ivrem rate so wol getrvnchen han ### mir ist geschenchet selten dehein bezzer win ### leb ich deheine wile ich sol ez dienende sin
###### 2173 | ### Do dandern daz gehorten daz ez in dvhte gvot ### do wart ir michel mere die trvnchen ovch daz blvot ### da von begunde chreften der gvten rechen lip ### des engalt an lieben frivnden sit vil manic schone wip
###### 2174 | ### Daz fivr <viel> genote zvo zin in den sal ### do leitten siz mit schilden von in hin zetal ### der rovch vn– ovch div hizze in beidiv taten we ### ia wæn ez an heleden der iamer immer mer erge
###### 2175 | ### Do sprach von Tronege Hagene stet zv des sales want ### lat niht die [78v]brende vallen vf iwer helmbant ### vn– tret si mit den fvzen tieferin daz blvot ### ez ist ein vbel hochgecit die vns div kvneginne tvot
| ### In svs getanen leiden in iedoch der naht zerran ### noch stvnden vor dem hvse die zwene chvne man ### Volker vn– Hagene geleinet vber rant ### si hvten ir gesindes vzer Burgonden lant
###### 2177 | ### Die geste half daz sere daz der sal gewelbet was ### da von ir deste mere in der not genas ### wan daz si zen venstern von fivre liten not ### do nerten sich die degene als in ir ellen daz gebot
###### 2178 | ### Do sprach der videlære nv ge wir in den sal ### so wellent die Hvnen wenen vber al ### wir sin in not erstorben div an vns ist getan ### si sehent vns begegene noch ir eteslichen gan
###### 2179 | ### Do sprach von Bvrgonden Giselher daz kint ### ich wæn ez tagen welle sich hebt ein chveler wint ### nv laze vns got von himele noch lieber cit geleben ### vns hat min swester Chriemh' ein arge hochgecite gegebn
###### 2180 | ### Do sprach aber einer ich chivse nv den tac ### sit daz ez vns bezzer wesn nine mac ### so bereitet ir ivch rechen ze strite deist vns not ### wir chomen doch nimmer hinnen daz wir mit eren ligen tot
| ### Der chvnich wolde wænen die geste wæren tot ### vn– ovch div kuniginne von des fivres not ### do lebt ir noch dar inne sehs hundert chvner man ### daz nie kunec deheiner bezzer degene gewan
###### 2182 | ### Der ellenden hvote hete wol ersehen ### daz noch die geste lebten swie vil in was geschehen ### ze schaden vn– ze leide den kvnigen vn– ir man ### man sah ir noch genvoge vil wol <gesunt> dort inne stan
###### 2183 | ### Man sagt der kuniginne ir wære vil genesen ### do sprach div frowe here daz enchvnde nimmer wesen ### <daz> ir deheiner lebte in des fivres not ### ich wil des baz getrowen daz si alle ligen tot
###### 2184 | ### Noch genæsen gerne die fvrsten vn– ir man ### ob in iemen hæte genade da getan ### den kunden si niht vinden an den von Hvnen lant ### do rachen si ir sterben mit vil willechlicher hant
###### 2185 | ### Vil frvo wider morgen grvzen man in bot ### mit starchem vrlivge des chomen helde in not ### do wart zvo zin geschozzin vil manic scharpfer ger ### noch fvnden si dar inne ze wer die reehen also her
###### 2186 | ### Dem Ezeln gesinde erwegt was der mvot ### si wolden vaste dienen daz Chriemh' gvot ### dar zv si wolden leisten daz in der kvnec gebot ### des chomen aber die degene in vil angestliche not
| ### Uon geheize vn– ovch von gabe man mohte wnder sagen ### dar hi[79r]ez si golt daz rote in den schilden tragen ### si gab ez swer sin rvochte vnde ez wolde enpfan ### iane wart nie grozer solden mer vf vinde getan
###### 2188 | ### Ein michel chraft der rechen dar zv gewafent gie ### do sprach der videlære wir sin et aber hie ### ine gesach zem tode nie helde gerner chomen ### die daz golt des kuniges vns ze vare hant genomen
###### 2189 | ### Do riefen ir genvge naher helede baz ### daz wir da svlen enden vn– tvon bezite daz ### hie belibet niemen wan doch der sterben sol ### do sahe man schiere ir schilde stechen gerschvzze vol
###### 2190 | ### Waz inag ich sagen mere wol zwelf hvndert man ### versvhten ez vil sere wider vn– dan ### do chvlten an den vinden die geste wol ir mvot ### ez enmohte niemen scheiden des sah man vliezen daz blvot
###### 2191 | ### von verchtiefen wnden der wart da vil geslagen ### do horte man genvoge nach ir <frivnden> chlagen ### die frvmen stvrben alle dem richen kvnige her ### des heten holde mage nach in iamer vn– ser

<<< Übersicht <<< vorige Seite nächste Seite >>>